==> jc-1.4.0.tar.gz: javax/swing/GrayFilter.h <==
// public class javax.swing.GrayFilter

// class file dependencies
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class 2c65218813eb3a68 java_awt_image_RGBImageFilter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14fdc556a3838d72 javax_swing_GrayFilter

// header file dependencies
// @dep_header java_awt_image_RGBImageFilter

#include "java/awt/image/RGBImageFilter.h"

#ifndef _JC_javax_swing_GrayFilter_H_
#define _JC_javax_swing_GrayFilter_H_

// Forward structure declarations
struct _jc_java_awt_Image$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_GrayFilter$sub_refs	_jc_javax_swing_GrayFilter$sub_refs;
typedef struct _jc_javax_swing_GrayFilter$sub_nonrefs	_jc_javax_swing_GrayFilter$sub_nonrefs;
typedef struct _jc_javax_swing_GrayFilter$refs	_jc_javax_swing_GrayFilter$refs;
typedef struct _jc_javax_swing_GrayFilter$nonrefs	_jc_javax_swing_GrayFilter$nonrefs;
typedef struct _jc_javax_swing_GrayFilter$object	_jc_javax_swing_GrayFilter$object;

typedef const struct _jc_javax_swing_GrayFilter$vmethods	_jc_javax_swing_GrayFilter$vmethods;
typedef const struct _jc_javax_swing_GrayFilter$vtable	_jc_javax_swing_GrayFilter$vtable;
typedef const struct _jc_javax_swing_GrayFilter$vtype	_jc_javax_swing_GrayFilter$vtype;

// Constructors
extern void _jc_javax_swing_GrayFilter$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_javax_swing_GrayFilter$object *, jboolean, jint);

// Virtual methods
extern jint _jc_javax_swing_GrayFilter$method$filterRGB$e652b7eda531500d(_jc_env *, struct _jc_javax_swing_GrayFilter$object *, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_GrayFilter$method_info$filterRGB$e652b7eda531500d;

// Static methods
extern struct _jc_java_awt_Image$object *_jc_javax_swing_GrayFilter$method$createDisabledImage$6b4ee5ef01f35378(_jc_env *, struct _jc_java_awt_Image$object *);

// Virtual methods structure
struct _jc_javax_swing_GrayFilter$vmethods {
	jint	(*filterRGB$e652b7eda531500d)(_jc_env *, struct _jc_javax_swing_GrayFilter$object *, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_GrayFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_RGBImageFilter$vmethods	java_awt_image_RGBImageFilter;
	_jc_javax_swing_GrayFilter$vmethods	javax_swing_GrayFilter;
};

// Vtype
struct _jc_javax_swing_GrayFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_GrayFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_GrayFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_GrayFilter$refs {
    _jc_javax_swing_GrayFilter$sub_refs	javax_swing_GrayFilter;
    _jc_java_awt_image_RGBImageFilter$sub_refs	java_awt_image_RGBImageFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_GrayFilter$sub_nonrefs {
	jboolean	b;
	jint	p;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_GrayFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_RGBImageFilter$sub_nonrefs	java_awt_image_RGBImageFilter;
    _jc_javax_swing_GrayFilter$sub_nonrefs	javax_swing_GrayFilter;
};

// Object instance structure
struct _jc_javax_swing_GrayFilter$object {
	_jc_javax_swing_GrayFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_GrayFilter$vtype	*vtype;
	_jc_javax_swing_GrayFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_GrayFilter$vtype _jc_javax_swing_GrayFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_GrayFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_GrayFilter$class_object;

#endif	/* _JC_javax_swing_GrayFilter_H_ */

==> jc-1.4.5.tar.gz: javax/swing/GrayFilter.h <==
// public class javax.swing.GrayFilter

// class file dependencies
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class 2c65218813eb3a68 java_awt_image_RGBImageFilter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14fdc556a3838d72 javax_swing_GrayFilter

// header file dependencies
// @dep_header java_awt_image_RGBImageFilter

#include "java/awt/image/RGBImageFilter.h"

#ifndef _JC_javax_swing_GrayFilter_H_
#define _JC_javax_swing_GrayFilter_H_

// Forward structure declarations
struct _jc_java_awt_Image$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_GrayFilter$sub_refs	_jc_javax_swing_GrayFilter$sub_refs;
typedef struct _jc_javax_swing_GrayFilter$sub_nonrefs	_jc_javax_swing_GrayFilter$sub_nonrefs;
typedef struct _jc_javax_swing_GrayFilter$refs	_jc_javax_swing_GrayFilter$refs;
typedef struct _jc_javax_swing_GrayFilter$nonrefs	_jc_javax_swing_GrayFilter$nonrefs;
typedef struct _jc_javax_swing_GrayFilter$object	_jc_javax_swing_GrayFilter$object;

typedef const struct _jc_javax_swing_GrayFilter$vmethods	_jc_javax_swing_GrayFilter$vmethods;
typedef const struct _jc_javax_swing_GrayFilter$vtable	_jc_javax_swing_GrayFilter$vtable;
typedef const struct _jc_javax_swing_GrayFilter$vtype	_jc_javax_swing_GrayFilter$vtype;

// Constructors
extern void _jc_javax_swing_GrayFilter$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_javax_swing_GrayFilter$object *, jboolean, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_GrayFilter$method$filterRGB$e652b7eda531500d(_jc_env *, struct _jc_javax_swing_GrayFilter$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_GrayFilter$method_info$filterRGB$e652b7eda531500d;

// Static methods
extern struct _jc_java_awt_Image$object *_jc_javax_swing_GrayFilter$method$createDisabledImage$6b4ee5ef01f35378(_jc_env *, struct _jc_java_awt_Image$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_GrayFilter$vmethods {
	jint	(*filterRGB$e652b7eda531500d)(_jc_env *, struct _jc_javax_swing_GrayFilter$object *, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_GrayFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_RGBImageFilter$vmethods	java_awt_image_RGBImageFilter;
	_jc_javax_swing_GrayFilter$vmethods	javax_swing_GrayFilter;
};

// Vtype
struct _jc_javax_swing_GrayFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_GrayFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_GrayFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_GrayFilter$refs {
    _jc_javax_swing_GrayFilter$sub_refs	javax_swing_GrayFilter;
    _jc_java_awt_image_RGBImageFilter$sub_refs	java_awt_image_RGBImageFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_GrayFilter$sub_nonrefs {
	jboolean	b;
	jint	p;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_GrayFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_RGBImageFilter$sub_nonrefs	java_awt_image_RGBImageFilter;
    _jc_javax_swing_GrayFilter$sub_nonrefs	javax_swing_GrayFilter;
};

// Object instance structure
struct _jc_javax_swing_GrayFilter$object {
	_jc_javax_swing_GrayFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_GrayFilter$vtype	*vtype;
	_jc_javax_swing_GrayFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_GrayFilter$vtype _jc_javax_swing_GrayFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_GrayFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_GrayFilter$class_object;

#endif	/* _JC_javax_swing_GrayFilter_H_ */
